@@ -6,10 +6,6 @@ pub mod alert_event_type_enum;
 pub use self::alert_event_type_enum::AlertEventTypeEnum;
 pub mod alert_request;
 pub use self::alert_request::AlertRequest;
-pub mod ansible_extra_vars;
-pub use self::ansible_extra_vars::AnsibleExtraVars;
-pub mod ansible_extra_vars_request;
-pub use self::ansible_extra_vars_request::AnsibleExtraVarsRequest;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
@@ -230,6 +226,8 @@ pub mod printer_profile_request;
 pub use self::printer_profile_request::PrinterProfileRequest;
 pub mod printer_state_enum;
 pub use self::printer_state_enum::PrinterStateEnum;
+pub mod printnanny_env_enum;
+pub use self::printnanny_env_enum::PrintnannyEnvEnum;
 pub mod release;
 pub use self::release::Release;
 pub mod release_channel_enum;
@@ -280,3 +278,5 @@ pub mod user;
 pub use self::user::User;
 pub mod user_request;
 pub use self::user_request::UserRequest;
+pub mod variant_enum;
+pub use self::variant_enum::VariantEnum;
